======
rev_ai
======


.. image:: https://img.shields.io/travis/revdotcom/revai-python-sdk.svg
        :target: https://travis-ci.org/revdotcom/revai-python-sdk



Rev.ai makes speech applications easy to build!


* Free software: MIT license
* Documentation: https://docs.rev.ai/en/latest/.
